# 基于python开发使用
## Python API使用说明

API（ApplicationProgrammingInterface），也称为应用程序编程接口函数，是预定义的函数。 使用以下功能接口时，请在开始时输入以下代码导入我们的 API 库，否则无法成功运行：

```python
# Example
from pymycobot import Phoenix

m = Phoenix()
m.start_robot()
print(m.get_angles())
```

## Phoenix(debug=False)

### 1.系统状态

#### start_robot(power_on_only=False)

启动机器人。

- **参数：**
  **power_on_only** (_bool_ _,_ _可选_) – 仅开机。 默认为 False。
- **退货：**
  如果启动成功则为 True，否则为 False。
- **返回类型：**
  布尔值

#### start_power_on_only()

打开机器人电源。

- **退货：**
  如果开机成功则为 True，否则为 False
- **返回类型：**
  布尔值

#### shutdown_robot()

关闭机器人。

#### set_state(s)

检查机器人的状态是否准备好运行。

目前仅检查运动启用标志。

- **退货：**
  如果机器人状态已准备好运行，则为 True，否则为 False。
- **返回类型：**
  布尔值

#### 获取机器人温度()

返回机器人（当前为 CPU）的温度。

- **退货：**
  机器人温度
- **返回类型：**
  漂浮

#### get_robot_power()

返回机器人当前消耗的功率，以瓦 (W) 为单位。

- **退货：**
  电流消耗功率
- **返回类型：**
  漂浮

#### 设置状态

将机器人状态更改为以下之一：
: elerob.STATE_ESTOP (1),
elerob.STATE_ESTOP_RESET (2),
elerob.STATE_OFF (3),
elerob.STATE_ON (4)

- **参数：**
  **s** (_str_) – 机器人状态，可以是“STATE_ON”、“STATE_OFF”、“STATE_ESTOP”，
  “STATE_ESTOP_RESET”。

### 2.整体状况

#### get_speed()

返回当前机器人的速度。

- **返回:**
  当前机器人的速度
- **返回类型:**
  float

#### set_feedrate(new_val)

以百分比（进给率）设置机器人速度。

- **参数:**
  **new_val** (_float_) – 速度值以百分比表示，0 ~ 100。

#### get_feedrate()

返回当前速度，1.0 = 100%。

- **返回:**
  当前速度
- **返回类型:**
  float

#### check_running()

如果机器人正在移动，则返回 True，否则返回 False。

- **返回:**
  如果机器人正在移动，则为 True，否则为 False
- **返回类型:**
  bool

#### set_payload(payload_weight)

设置当前有效负载重量。

- **参数:**
  **payload_weight** (_float_) – 有效负载重量（公斤）

#### get_payload()

返回当前有效负载。

- **返回:**
  有效负载值（公斤）
- **返回类型:**
  float

#### get_error()

读取下一个错误并以元组形式返回类型、错误代码、描述。

- **返回:**
  错误信息
- **返回类型:**
  tuple[str, int, str]

#### get_task_mode()

返回当前任务模式。

- **返回:**
  TaskMode 枚举值之一：AUTO、MANUAL、MDI
- **返回类型:**
  [TaskMode](#class-phoenixtaskmodevalue)

#### set_task_mode(task_mode)

将任务模式设置为给定模式。

- **参数:**
  **mode** ([_TaskMode_](#class-phoenixtaskmodevalue)) – TaskMode.AUTO、TaskMode.MANUAL、TaskMode.MDI 之一
- **返回:**
  总是返回 True
- **返回类型:**
  bool

#### set_estop_reset()

重置机器人的 E-Stop（紧急停止）状态。

#### set_estop()

将机器人置于 E-Stop（紧急停止）状态。

#### get_acceleration()

返回机器人的加速度值。

- **返回:**
  加速度值
- **返回类型:**
  float

#### is_cnc_in_mdi_mode()

检查机器人是否处于 MDI 模式。

- **返回:**
  如果机器人处于 MDI 模式，则为 True
- **返回类型:**
  bool

#### set_cnc_in_mdi_mode()

将机器人模式设置为 MDI。

#### get_motion_line()

返回当前正在执行的运动文件的行号
（先前打开的 g-code 文件）。

- **返回:**
  正在运行的行号
- **返回类型:**
  int

#### is_in_commanded_position()

返回机器就位标志。 如果命令位置为 True
等于实际位置。

- **返回:**
  机器就位标志
- **返回类型:**
  bool

#### set_acceleration(acceleration)

设置机器人的加速度。

- **参数:**
  **acceleration** (_float_) – 新的加速度值

#### is_task_idle()

如果程序未运行或未完成，则返回 True。

- **返回:**
  如果程序未运行或未完成，则为 True，否则为 False。
- **返回类型:**
  bool

#### is_program_running(do_poll=True)

检查机器人是否正在执行程序。

- **参数:**
  **do_poll** (_bool_ _,_ _可选_) – 是否需要更新机器人状态。 默认为 True。
- **返回:**
  如果机器人正在执行程序则为 True，否则为 False
- **返回类型:**
  bool

#### program_open(program_file_path)

打开 g-code 文件。 仅支持绝对文件路径。

- **参数:**
  **program_file_path** (_str_) – 程序文件 (.ngc) 的绝对路径

#### program_run(start_line)

从给定行开始运行 g-code 文件。

- **参数:**
  **start_line** (_int_) – 起始行（第一行为 0）

#### get_current_line()

返回 g-code 文件的当前执行行。

- **返回:**
  current executing line
- **返回类型:**
  int

#### get_current_gcodes()

获取当前执行的 G-code。

返回每个模态组的活动 G-code。

- **返回:**
  active G-codes
- **返回类型:**
  tuple of integers

#### get_read_line()

获取 G-code 解释器读取行。

- **返回:**
  G-code 解释器读取行
- **返回类型:**
  int

#### set_max_velocity(velocity)

设置最大速度。

- **参数:**
  **velocity** (_float_) – 设置的最大速度，百分比，0 ~ 100。

#### prog_exec_status()

返回 G-code 解释器的当前状态。

- **返回:**
  解释器的当前状态: INTERP_IDLE (1),
  : INTERP_READING (2),
  INTERP_PAUSED (3),
  INTERP_WAITING (4)
- **返回类型:**
  int

#### elerob_status()

返回当前任务状态。

- **返回:**
  当前任务状态，其中之一:
  : elerob.STATE_ESTOP (1),
  elerob.STATE_ESTOP_RESET (2),
  elerob.STATE_OFF (3),
  elerob.STATE_ON (4)
- **返回类型:**
  int

#### optional_stop_resume()

可选停止后恢复程序。

#### program_pause()

暂停当前正在运行的程序。

#### program_resume()

暂停后恢复程序。

#### task_stop()

停止机器人并等待停止完成。

#### task_stop_async()

无需等待停止完成即可停止机器人。

#### get_current_velocity()

返回当前速度。

- **返回:**
  当前速度（每秒单位）
- **返回类型:**
  float

#### get_default_velocity()

返回默认速度。

- **返回:**
  默认速度
- **返回类型:**
  float

#### get_default_acceleration()

返回默认加速度

- **返回:**
  默认加速度
- **返回类型:**
  float

#### get_max_velocity()

返回最大速度。

- **返回:**
  最大速度
- **返回类型:**
  float

#### get_max_acceleration()

返回最大加速度。

- **返回：**
  最大加速度
- **返回类型:**
  float

#### set_carte_torque_limit(axis, value)

设置笛卡尔扭矩限制。

- **参数：**
  - **axis** ([_Axis_](#class-phoenixaxisvalue)) – 设置扭矩的轴
  - **value** (_float_) – 扭矩值

### 3.MDI 模式及操作

#### get_coords()

以列表[X, Y, Z, RX, RY, RZ]的形式返回当前机器人坐标。

- **返回：**
  每个轴 6 个浮点值的列表
- **返回类型:**
  list[float]

#### set_coords(coords, speed)

以指定速度将机器人移动到给定坐标。
给定坐标为列表[X, Y, Z, RX, RY, RZ]。

- **参数：**
  - **coords** (_list_ _[\*\*float_ _]_) – 要设置的坐标，list[float] 大小为 6
  - **speed** (_float_) – 速度百分比 (0 ~ 100 %)

#### get_coord(axis)

返回指定轴的当前坐标。

- **参数：**
  **axis** ([_Axis_](#class-phoenixaxisvalue)) – Axis.X ~ Axis.RZ
- **返回:**
  current coord of specified axis
- **返回类型:**
  float

#### set_coord(axis, coord, speed)

将机器人给定坐标移动到指定值，以设置的速度进行移动。

- **参数:**
  - **axis** ([_Axis_](#class-phoenixaxisvalue)) – 轴。可选值：Axis.X ~ Axis.RZ
  - **coord** (_float_) – 坐标值
  - **speed** (_float_) – 速度百分比 (1 ~ 100 %)

#### get_angles()

返回机器人当前的关节角度值。

- **返回:**
  当前角度列表[float]，大小为 MAX_JOINTS
- **返回类型:**
  list[float]

#### set_angles(angles, speed)

将机器人的关节角度移动到指定的值，以给定的速度。

- **参数:**
  - **angles** (_list[float]_) – 关节角度，大小为 MAX_JOINTS 的 float 列表
  - **speed** (_float_) – 速度百分比 (1 ~ 100 %)

#### get_angle(joint)

返回机器人指定关节的当前角度。

- **参数:**
  **joint** ([_Joint_](#class-phoenixjointvalue)) – Joint.J1 (0) ~ Joint.J6 (5)
- **返回:**
  指定关节的角度
- **返回类型:**
  float

#### set_angle(joint, angle, speed)

将机器人指定关节的角度移动到给定值，以传递的速度。

- **参数:**
  - **joint** ([_Joint_](#class-phoenixjointvalue)) – 0 ~ 5 或 Joint.J1 ~ Joint.J6
  - **angle** (_float_) – 要设置的角度
  - **speed** (_float_) – 速度百分比 (0 ~ 100 %)

#### is_in_position(coords, jog_mode)

如果当前位置等于传递的坐标，则返回 True。

- **参数:**
  - **coords** (_list[float]_) – 坐标或角度
  - **jog_mode** ([_JogMode_](#class-phoenixjogmodevalue)) – JogMode 枚举值
- **返回:**
  如果机器人处于传递的坐标中，则返回 True，否则返回 False
- **返回类型:**
  bool

#### set_free_move_mode(on=True)

启用或禁用自由移动模式。

- **参数:**
  **on** (_bool_ _,_ _optional_) – True 表示启用自由移动模式，
  False 表示禁用自由移动模式。
  默认为 True。
- **返回:**
  如果成功则返回 True，否则返回 False
- **返回类型:**
  bool

#### is_software_free_move()

检查自由移动模式是否由 set_free_move_mode() 函数或其他类似 API（来自 Phoenix）启用。

- **返回:**
  如果软件启用了自由移动模式，则返回 True，否则返回 False
- **返回类型:**
  bool

#### is_hardware_free_move()

确定机器人手臂末端的按钮是否被按下。

- **返回:**
  如果自由移动模式由硬件（按钮）启用，则返回 True
- **返回类型:**
  bool

#### is_program_run_finished()

检查程序是否已经运行结束。

- **返回:**
  如果程序已经运行结束，则返回 True，否则返回 False
- **返回类型:**
  bool

#### is_program_paused()

检查程序运行是否暂停。

- **返回:**
  如果程序已经暂停，则返回 True，否则返回 False
- **返回类型:**
  bool

#### send_home(axis_num=-1)

对指定轴或所有轴进行回零操作（-1 表示对所有轴进行回零操作）。
回零操作会将当前关节或轴的值设为原点位置。

- **参数:**
  **axis_num** (_int_ _,_ _optional_) – 要回零的轴。-1 表示对所有轴进行回零操作。
  默认为 -1。

#### is_all_homed()

检查所有轴是否已回零（处于原点位置）。

- **返回:**
  如果所有轴已回零，则返回 True，否则返回 False。
- **返回类型:**
  bool

#### get_axis_velocity(axis)

返回轴的速度。

- **参数:**
  **axis** ([_Axis_](#class-phoenixaxisvalue)) – 轴编号
- **返回:**
  轴的速度，如果出错则返回 -1.0
- **返回类型:**
  float

#### get_current_command()

返回当前正在执行的命令。

- **返回:**
  当前正在执行的命令
- **返回类型:**
  str

### 4. JOG 模式及操作

#### jog_angle(joint, direction, speed)

以指定的方向和速度开始关节运动。

- **参数:**
  - **joint** ([_Joint_](#class-phoenixjointvalue)) – Joint.J1 ~ Joint.J6
  - **direction** ([_JogDirection_](#class-phoenixjogdirectionvalue)) – JogDirection.POSITIVE (1) 或 JogDirection.NEGATIVE (-1)（1 - 增加，-1 - 减少）
  - **speed** (_float_) – 速度百分比（0 ~ 100 %）
- **返回:**
  如果成功开始关节运动，则返回 True，否则返回 False
- **返回类型:**
  bool

#### jog_coord(axis, direction, speed)

以指定的方向和速度开始坐标轴运动。

- **参数:**
  - **axis** ([_Axis_](#class-phoenixaxisvalue)) – Axis.X ~ Axis.RZ, 对应 x ~ rz
  - **direction** ([_JogDirection_](#class-phoenixjogdirectionvalue)) – JogDirection.POSITIVE (1) 增加，JogDirection.NEGATIVE (-1) 减少
  - **speed** (_float_) – 速度百分比（1 ~ 100 %）
- **返回:**
  如果成功开始坐标轴运动，则返回 True，否则返回 False
- **返回类型:**
  bool

#### jog_increment_angle(joint, increment, speed)

以给定的增量和速度移动指定的关节。

- **参数:**
  - **joint** ([_Joint_](#class-phoenixjointvalue)) – 关节
  - **increment** (_float_) – 角度增量
  - **speed** (_float_) – 速度百分比（0 ~ 100 %）
- **返回:**
  如果成功开始关节运动，则返回 True，否则返回 False
- **返回类型:**
  bool

#### jog_increment_coord(axis, increment, speed)

以给定的增量值和速度移动指定的坐标轴。

- **参数:**
  - **axis** ([_Axis_](#class-phoenixaxisvalue)) – 坐标轴
  - **increment** (_float_) – 增量
  - **speed** (_float_) – 速度百分比（0 ~ 100）
- **返回:**
  如果成功开始坐标轴运动，则返回 True，否则返回 False
- **返回类型:**
  bool

#### jog_stop(jog_mode, joint_or_axis)

停止指定的关节或坐标轴运动。

- **参数:**
  - **jog_mode** ([_JogMode_](#class-phoenixjogmodevalue)) – JogMode.JOG_TELEOP（坐标轴（0））或 JogMode.JOG_JOINT（关节（1））
  - **joint_or_axis** ([_Joint_](#class-phoenixjointvalue) _|_ [_Axis_](#class-phoenixaxisvalue)) – 关节（Joint.J1 ~ Joint.J6）或坐标轴（Axis.X ~ Axis.RZ）
- **返回:**
  如果成功停止运动，则返回 True，否则返回 False
- **返回类型:**
  bool

#### jog_stop_all()

停止任何关节或坐标轴的运动。

- **返回:**
  总是返回 True
- **返回类型:**
  bool

### 5. 限位操作

#### get_joint_min_pos_limit(joint)

返回指定关节的最小位置限制值。

- **参数:**
  **joint_number** ([_Joint_](#class-phoenixjointvalue)) – Joint.J1 ~ Joint.J6
- **返回:**
  指定关节的最小位置限制值
- **返回类型:**
  float

#### set_joint_min_pos_limit(joint, limit)

设置指定关节的最小位置限制值。

- **参数:**
  - **joint_number** ([_Joint_](#class-phoenixjointvalue)) – Joint.J1 ~ Joint.J6
  - **limit** (_float_) – 指定关节的最小位置限制值

#### get_joint_max_pos_limit(joint)

返回指定关节的最大位置限制值。

- **参数:**
  **joint_number** ([_Joint_](#class-phoenixjointvalue)) – Joint.J1 ~ Joint.J6
- **返回:**
  指定关节的最大位置限制值
- **返回类型:**
  float

#### set_joint_max_pos_limit(joint, limit)

设置指定关节的最大位置限制值。

- **参数:**
  - **joint_number** ([_Joint_](#class-phoenixjointvalue)) – Joint.J1 ~ Joint.J6
  - **limit** (_float_) – 指定关节的最大位置限制值

#### get_axis_limits()

返回轴的限制值。

- **返回:**
  轴的限制值
- **返回类型:**
  list[int]

### 6. 关节电机控制

#### is_servo_enabled(joint)

检查指定关节的伺服是否已启用。

- **参数:**
  **joint** ([_Joint_](#class-phoenixjointvalue)) – Joint.J1 ~ Joint.J6
- **返回:**
  如果伺服已启用，则为 True，否则为 False
- **返回类型:**
  bool

#### is_all_servo_enabled()

检查是否所有伺服都已启用。

- **返回:**
  如果所有伺服都已启用，则为 True，否则为 False
- **返回类型:**
  bool

#### release_joint_brake(joint, release=True)

释放或锁定（启用）指定关节的制动器。

- **参数:**
  - **joint** ([_Joint_](#class-phoenixjointvalue)) – Joint.J1 ~ Joint.J6
  - **release** (_bool_) – True 释放，False 锁定制动器，默认为 True。

#### get_joint_state(joint)

返回指定关节的状态。

- **参数:**
  **joint** ([_Joint_](#class-phoenixjointvalue)) – Joint.J1 ~ Joint.J6
- **返回:**
  关节状态
- **返回类型:**
  [JointState](#class-phoenixjointvalueState)

#### get_joint_temperature(joint)

返回指定关节的温度。

- **参数:**
  **joint** ([_Joint_](#class-phoenixjointvalue)) – Joint.J1 ~ Joint.J6
- **返回:**
  温度
- **返回类型:**
  float

#### get_joint_communication(joint)

返回如果指定关节的通讯正常，则为 True。

- **参数:**
  **joint** ([_Joint_](#class-phoenixjointvalue)) – Joint.J1 ~ Joint.J6
- **返回:**
  如果关节通讯正常，则为 True，否则为 False
- **返回类型:**
  bool

#### get_joint_voltage(joint)

返回指定关节的电压。

- **参数:**
  **joint** ([_Joint_](#class-phoenixjointvalue)) – Joint.J1 ~ Joint.J6
- **返回:**
  电压
- **返回类型:**
  float

#### get_joint_current(joint)

返回指定关节的电流。

- **参数:**
  **joint** ([_Joint_](#class-phoenixjointvalue)) – Joint.J1 ~ Joint.J6
- **返回:**
  电流
- **返回类型:**
  float

#### get_joint_error_mask(joint)

返回指定关节的错误掩码。

- **参数:**
  **joint** ([_Joint_](#class-phoenixjointvalue)) – Joint.J1 ~ Joint.J6
- **返回:**
  错误掩码
- **返回类型:**
  int

#### clear_encoder_error(servo_id)

清除伺服的编码器错误。

- **参数:**
  **servo_id** ([_Joint_](#class-phoenixjointvalue)) – Joint 枚举值之一

#### set_joint_torque_limit(joint, torque_limit)

设置关节的扭矩限制。

- **参数:**
  - **joint** ([_Joint_](#class-phoenixjointvalue)) – 关节
  - **torque_limit** (_float_) – 扭矩限制值

### 7. 底座 IO 控制

#### get_digital_in(pin_number)

返回数字输入引脚的值。DI 枚举之一。

- **参数:**
  **pin_number** ([_DI_](#class-phoenixdivalue)) – 引脚编号
- **返回:**
  引脚值 (0 或 1)
- **返回类型:**
  int

#### get_digital_out(pin_number)

返回数字输出引脚的值。DO 枚举之一。

- **参数:**
  **pin_number** ([_DO_](#class-phoenixdivalue)) – 引脚编号
- **返回:**
  引脚值 (0 或 1)
- **返回类型:**
  int

#### set_digital_out(pin_number, pin_value)

设置数字输出引脚的值。DO 枚举之一。

- **参数:**
  - **pin_number** ([_DO_](#class-phoenixdivalue)) – 引脚编号
  - **pin_value** (_int_) – 引脚值 (0 或 1)

#### get_analog_in(pin_number)

返回模拟输入引脚的值。AI 枚举之一。

- **参数:**
  **pin_number** ([_AI_](#class-phoenixaivalue)) – 引脚编号
- **返回:**
  引脚值
- **返回类型:**
  float

#### get_analog_out(pin_number)

返回模拟输出引脚的值。AO 枚举之一。

- **参数:**
  **pin_number** ([_AO_](#class-phoenixaovalue)) – 引脚编号
- **返回:**
  引脚值
- **返回类型:**
  float

#### set_analog_out(pin_number, pin_value)

设置模拟输出引脚的值。AO 枚举之一。

- **参数:**
  - **pin_number** ([_AO_](#class-phoenixaovalue)) – 引脚编号
  - **pin_value** (_float_) – 引脚值

### 8. 末端夹爪控制

#### tool_set_gripper_calibrate()

设置夹爪当前位置为零位

#### tool_set_gripper_enabled(enabled)

启用或禁用夹爪。

- **参数:**
  **enabled** (_bool_) – 如果启用，则为 True，如果禁用，则为 False

#### tool_set_gripper_mode(mode)

设置夹爪模式。

- **参数:**
  **mode** (_int_) – 夹爪模式

#### tool_set_gripper_state(state, speed)

设置夹爪状态。

- **参数:**
  - **state** (_int_) – 状态
  - **speed** (_int_) – 速度

#### tool_set_gripper_value(value, speed)

设置夹爪值。

- **参数:**
  - **value** (_int_) – 值
  - **speed** (_int_) – 速度

### 9. 末端按钮以及灯光控制

#### tool_is_btn_clicked()

如果 ESP32 按钮被按下则返回 True。

- **返回:**
  如果按钮被按下则为 True，否则为 False
- **返回类型:**
  bool

#### tool_set_led_color(r, g, b)

设置 ESP32 LED 的 RGB 颜色。

- **参数:**
  - **r** (_int_) – 红色值 (0-255)
  - **g** (_int_) – 绿色值 (0-255)
  - **b** (_int_) – 蓝色值 (0-255)

### 10. 末端 IO 控制

#### tool_get_firmware_version()

返回 ESP32 Pico 固件版本。

- **返回:**
  固件版本
- **返回类型:**
  float

#### tool_set_digital_out(pin_no, pin_value)

设置 ESP32 上的数字输出引脚。

- **参数:**
  - **pin_no** (_int_) – 引脚编号
  - **pin_value** (_int_) – 引脚值 (0 或 1)

#### tool_get_digital_in(pin_no)

返回数字输入引脚的值。

- **参数:**
  **pin_no** (_int_) – 引脚编号
- **返回:**
  引脚值
- **返回类型:**
  int

### 11.末端串口通信控制

#### tool_serial_restore()

恢复 ESP32 串口。

#### tool_serial_is_ready()

返回 True 如果 ESP32 串口准备就绪。

#### tool_serial_available()

返回 True 如果 ESP32 串口可用。

- **返回:**
  如果串口可用返回 True，否则返回 False
- **返回类型:**
  bool

#### tool_serial_read_data(n)

读取并返回可用的串口数据。

- **参数:**
  **n** (_int_) – 要读取的字节数
- **返回:**
  从串口读取的字节列表
- **返回类型:**
  list[int]

#### tool_serial_write_data(bytes)

将数据写入 ESP32 串口。

- **参数:**
  **bytes** (_list_ _[\*\*int_ _]_) – 要写入的数据
- **返回:**
  实际写入的字节数
- **返回类型:**
  int

#### tool_serial_flush()

刷新 ESP32 串口缓冲区。

- **返回:**
  如果准备就绪返回 True，否则返回 False
- **返回类型:**
  bool

#### tool_serial_peek()

从 ESP32 串口缓冲区中读取一个字节。

- **返回:**
  读取的字节
- **返回类型:**
  int

#### tool_serial_set_baudrate(baudrate)

设置 ESP32 串口的波特率。

- **参数:**
  **baudrate** (_int_) – 波特率

#### tool_serial_set_timeout(timeout)

设置 ESP32 串口的超时时间（单位：毫秒）。

- **参数:**
  **timeout** (_int_) – 超时时间（毫秒）

---

### _class_ phoenix.RobotMoveState(value)

Bases: `Enum`

An enumeration.

#### IDLE_STATE _= 0_

#### JOG_AXIS_STATE _= 2_

#### JOG_JOINT_STATE _= 1_

#### MOVE_AXIS_STATE _= 3_

#### MOVE_JOINT_STATE _= 4_

#### RUN_PROGRAM_STATE _= 5_

### _class_ phoenix.Robots(value)

Bases: `Enum`

An enumeration.

#### CAT_3 _= 301_

#### ELEPHANT _= 101_

#### MY_COB _= 401_

#### MY_COB_PRO _= 402_

#### PANDA_3 _= 201_

#### PANDA_5 _= 202_

#### PRO_320 _= 501_

#### PRO_600 _= 502_

### _class_ phoenix.TaskMode(value)

Bases: `Enum`

An enumeration.

#### AUTO _= 2_

#### MANUAL _= 1_

#### MDI _= 3_

### _class_ phoenix.AI(value)

Bases: `Enum`

Available Analog Input Pins.

#### CONTROLLER_TEMPERATURE _= 57_

#### J1_CURRENT _= 58_

#### J1_TEMPERATURE _= 37_

#### J1_VOLTAGE _= 31_

#### J1_WINDING_A_CURRENT _= 43_

#### J1_WINDING_B_CURRENT _= 49_

#### J2_CURRENT _= 59_

#### J2_TEMPERATURE _= 38_

#### J2_VOLTAGE _= 32_

#### J2_WINDING_A_CURRENT _= 44_

#### J2_WINDING_B_CURRENT _= 50_

#### J3_CURRENT _= 60_

#### J3_TEMPERATURE _= 39_

#### J3_VOLTAGE _= 33_

#### J3_WINDING_A_CURRENT _= 45_

#### J3_WINDING_B_CURRENT _= 51_

#### J4_CURRENT _= 61_

#### J4_TEMPERATURE _= 40_

#### J4_VOLTAGE _= 34_

#### J4_WINDING_A_CURRENT _= 46_

#### J4_WINDING_B_CURRENT _= 52_

#### J5_CURRENT _= 62_

#### J5_TEMPERATURE _= 41_

#### J5_VOLTAGE _= 35_

#### J5_WINDING_A_CURRENT _= 47_

#### J5_WINDING_B_CURRENT _= 53_

#### J6_CURRENT _= 63_

#### J6_TEMPERATURE _= 42_

#### J6_VOLTAGE _= 36_

#### J6_WINDING_A_CURRENT _= 48_

#### J6_WINDING_B_CURRENT _= 54_

#### PIN_0 _= 0_

#### PIN_1 _= 1_

#### PIN_10 _= 10_

#### PIN_11 _= 11_

#### PIN_12 _= 12_

#### PIN_13 _= 13_

#### PIN_14 _= 14_

#### PIN_15 _= 15_

#### PIN_16 _= 16_

#### PIN_17 _= 17_

#### PIN_18 _= 18_

#### PIN_19 _= 19_

#### PIN_2 _= 2_

#### PIN_20 _= 20_

#### PIN_21 _= 21_

#### PIN_22 _= 22_

#### PIN_23 _= 23_

#### PIN_24 _= 24_

#### PIN_25 _= 25_

#### PIN_26 _= 26_

#### PIN_27 _= 27_

#### PIN_28 _= 28_

#### PIN_29 _= 29_

#### PIN_3 _= 3_

#### PIN_30 _= 30_

#### PIN_4 _= 4_

#### PIN_5 _= 5_

#### PIN_6 _= 6_

#### PIN_7 _= 7_

#### PIN_8 _= 8_

#### PIN_9 _= 9_

#### ROBOT _= 55_

#### ROBOT_AVG_POWER _= 56_

### _class_ phoenix.AO(value)

Bases: `Enum`

Available Analog Output Pins.

#### ACCELERATION _= 41_

#### J1_TORQUE _= 56_

#### J2_TORQUE _= 57_

#### J3_TORQUE _= 58_

#### J4_TORQUE _= 59_

#### J5_TORQUE _= 60_

#### J6_TORQUE _= 61_

#### LED_LIGHT _= 16_

#### PAYLOAD _= 53_

#### PIN_0 _= 0_

#### PIN_1 _= 1_

#### PIN_10 _= 10_

#### PIN_11 _= 11_

#### PIN_12 _= 12_

#### PIN_13 _= 13_

#### PIN_14 _= 14_

#### PIN_15 _= 15_

#### PIN_17 _= 17_

#### PIN_18 _= 18_

#### PIN_19 _= 19_

#### PIN_2 _= 2_

#### PIN_20 _= 20_

#### PIN_21 _= 21_

#### PIN_22 _= 22_

#### PIN_23 _= 23_

#### PIN_24 _= 24_

#### PIN_25 _= 25_

#### PIN_26 _= 26_

#### PIN_27 _= 27_

#### PIN_28 _= 28_

#### PIN_29 _= 29_

#### PIN_3 _= 3_

#### PIN_30 _= 30_

#### PIN_31 _= 31_

#### PIN_32 _= 32_

#### PIN_33 _= 33_

#### PIN_34 _= 34_

#### PIN_35 _= 35_

#### PIN_36 _= 36_

#### PIN_37 _= 37_

#### PIN_38 _= 38_

#### PIN_39 _= 39_

#### PIN_4 _= 4_

#### PIN_40 _= 40_

#### PIN_42 _= 42_

#### PIN_43 _= 43_

#### PIN_44 _= 44_

#### PIN_45 _= 45_

#### PIN_46 _= 46_

#### PIN_47 _= 47_

#### PIN_5 _= 5_

#### PIN_54 _= 54_

#### PIN_55 _= 55_

#### PIN_6 _= 6_

#### PIN_7 _= 7_

#### PIN_8 _= 8_

#### PIN_9 _= 9_

#### POWER_LIMIT _= 52_

#### STOPPING_DISTANCE _= 50_

#### STOPPING_TIME _= 51_

#### TOOL_FORCE _= 48_

#### TOOL_SPEED _= 49_

#### XY_AXIS_TORQUE _= 62_

#### Z_AXIS_TORQUE _= 63_

### _class_ phoenix.Axis(value)

Bases: `Enum`

An enumeration.

#### RX _= 3_

#### RY _= 4_

#### RZ _= 5_

#### X _= 0_

#### Y _= 1_

#### Z _= 2_

### phoenix.CPUTemperature()

### _class_ phoenix.DI(value)

Bases: `Enum`

Available Digital Input Pins.

#### BRAKE_ACTIVATION_RUNNING _= 44_

#### CAT_PHYSICAL_START _= 15_

#### CAT_PHYSICAL_STOP _= 16_

#### CAT_PHYSICAL_USER_DEFINE _= 17_

#### EMERGENCY_STOP _= 62_

#### HARDWARE_FREE_MOVE _= 51_

#### HARDWARE_PAUSE_PRESSED _= 43_

#### IO_RUN_TRIGGERED _= 41_

#### IO_STOP_TRIGGERED _= 40_

#### J1_COMMUNICATION _= 34_

#### J1_SERVO_ENABLED _= 45_

#### J1_STATUS _= 56_

#### J2_COMMUNICATION _= 35_

#### J2_SERVO_ENABLED _= 46_

#### J2_STATUS _= 57_

#### J3_COMMUNICATION _= 36_

#### J3_SERVO_ENABLED _= 47_

#### J3_STATUS _= 58_

#### J4_COMMUNICATION _= 37_

#### J4_SERVO_ENABLED _= 48_

#### J4_STATUS _= 59_

#### J5_COMMUNICATION _= 38_

#### J5_SERVO_ENABLED _= 49_

#### J5_STATUS _= 60_

#### J6_COMMUNICATION _= 39_

#### J6_SERVO_ENABLED _= 50_

#### J6_STATUS _= 61_

#### MOTION_ENABLE _= 52_

#### PIN_0 _= 0_

#### PIN_1 _= 1_

#### PIN_10 _= 10_

#### PIN_11 _= 11_

#### PIN_12 _= 12_

#### PIN_13 _= 13_

#### PIN_14 _= 14_

#### PIN_18 _= 18_

#### PIN_19 _= 19_

#### PIN_2 _= 2_

#### PIN_20 _= 20_

#### PIN_21 _= 21_

#### PIN_22 _= 22_

#### PIN_23 _= 23_

#### PIN_24 _= 24_

#### PIN_25 _= 25_

#### PIN_26 _= 26_

#### PIN_27 _= 27_

#### PIN_28 _= 28_

#### PIN_29 _= 29_

#### PIN_3 _= 3_

#### PIN_30 _= 30_

#### PIN_31 _= 31_

#### PIN_32 _= 32_

#### PIN_33 _= 33_

#### PIN_4 _= 4_

#### PIN_42 _= 42_

#### PIN_5 _= 5_

#### PIN_53 _= 53_

#### PIN_54 _= 54_

#### PIN_55 _= 55_

#### PIN_6 _= 6_

#### PIN_7 _= 7_

#### PIN_8 _= 8_

#### PIN_9 _= 9_

#### POWER_ON_STATUS _= 63_

### _class_ phoenix.DO(value)

Bases: `Enum`

Available Digital Output Pins.

#### BRAKE_ACTIVE_AUTO _= 47_

#### BRAKE_MANUAL_MODE_ENABLE _= 48_

#### J1_BRAKE_RELEASE _= 49_

#### J2_BRAKE_RELEASE _= 50_

#### J3_BRAKE_RELEASE _= 51_

#### J4_BRAKE_RELEASE _= 52_

#### J5_BRAKE_RELEASE _= 53_

#### J6_BRAKE_RELEASE _= 54_

#### PIN_0 _= 0_

#### PIN_1 _= 1_

#### PIN_10 _= 10_

#### PIN_11 _= 11_

#### PIN_12 _= 12_

#### PIN_13 _= 13_

#### PIN_14 _= 14_

#### PIN_15 _= 15_

#### PIN_16 _= 16_

#### PIN_17 _= 17_

#### PIN_18 _= 18_

#### PIN_19 _= 19_

#### PIN_2 _= 2_

#### PIN_20 _= 20_

#### PIN_21 _= 21_

#### PIN_22 _= 22_

#### PIN_23 _= 23_

#### PIN_24 _= 24_

#### PIN_25 _= 25_

#### PIN_26 _= 26_

#### PIN_27 _= 27_

#### PIN_28 _= 28_

#### PIN_29 _= 29_

#### PIN_3 _= 3_

#### PIN_30 _= 30_

#### PIN_31 _= 31_

#### PIN_32 _= 32_

#### PIN_33 _= 33_

#### PIN_34 _= 34_

#### PIN_35 _= 35_

#### PIN_36 _= 36_

#### PIN_37 _= 37_

#### PIN_38 _= 38_

#### PIN_39 _= 39_

#### PIN_4 _= 4_

#### PIN_40 _= 40_

#### PIN_41 _= 41_

#### PIN_42 _= 42_

#### PIN_43 _= 43_

#### PIN_44 _= 44_

#### PIN_45 _= 45_

#### PIN_46 _= 46_

#### PIN_5 _= 5_

#### PIN_59 _= 59_

#### PIN_6 _= 6_

#### PIN_61 _= 61_

#### PIN_62 _= 62_

#### PIN_63 _= 63_

#### PIN_7 _= 7_

#### PIN_8 _= 8_

#### PIN_9 _= 9_

#### POWER_ON_RELAY_1 _= 57_

#### POWER_ON_RELAY_2 _= 58_

#### PROGRAM_AUTO_RUNNING _= 56_

#### SKIP_INIT_ERRORS _= 55_

#### SOFTWARE_FREE_MOVE _= 60_

### _class_ phoenix.JogDirection(value)

Bases: `Enum`

An enumeration.

#### NEGATIVE _= -1_

#### POSITIVE _= 1_

### _class_ phoenix.JogMode(value)

Bases: `Enum`

An enumeration.

#### JOG_JOINT (angles)

#### JOG_TELEOP (coords)

### _class_ phoenix.Joint(value)

Bases: `Enum`

An enumeration.

#### J1 _= 0_

#### J2 _= 1_

#### J3 _= 2_

#### J4 _= 3_

#### J5 _= 4_

#### J6 _= 5_

### _class_ phoenix.JointState(value)

Bases: `Enum`

An enumeration.

#### ERROR _= 1_

#### OK _= 0_

#### POWERED_OFF _= 2_

---
[← 上一页](../6-SDKDevelopment.md) | [下一页 → ](../../11-ApplicationBaseROS/11.1-ROS1/README.md)